@@ -2,19 +2,16 @@
 /**
  * setup.php
  *
- * Copyright (c) 1999-2005 The SquirrelMail Project Team
+ * Copyright (c) 1999-2006 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * Uses standard plugin format to create a couple of forms to
  * enable import/export of CSV files to/from the address book.
- * @version $Id: setup.php,v 1.5 2005/03/16 17:04:00 tokul Exp $
+ * @version $Id: setup.php,v 1.13 2006/07/29 07:17:10 tokul Exp $
  * @package sm-plugins
  * @subpackage abook_import_export
  */
 
-/** @ignore */
-if (!defined('SM_PATH')) define('SM_PATH','../../');
-
 /**
  * Init plugin
  */
@@ -28,8 +25,7 @@ function squirrelmail_plugin_init_abook_import_export() {
  * @return string version number
  */
 function abook_import_export_version() {
-    include_once(SM_PATH . 'plugins/abook_import_export/functions.php');
-    return aie_version();
+    return '1.0';
 }
 
 /**
@@ -39,4 +35,3 @@ function abook_import_export() {
     include_once(SM_PATH . 'plugins/abook_import_export/functions.php');
     aie_create_form();
 }
-?>
